@@ -13,7 +13,7 @@ This is the complete API reference:
    readout_platform
 """
 
-__version__ = "0.0.2"  # denote a pre-release for 0.1.0 with 0.1a1
+__version__ = "0.0.3"  # denote a pre-release for 0.1.0 with 0.1a1
 
-from . import literal  # noqa
+from . import vocabulary  # noqa
 from ._core import readout_platform, readout_type  # noqa
