@@ -1,10 +1,10 @@
 from collections import namedtuple
-from typing import get_args  # noqa
+from typing import _LiteralGenericAlias, get_args  # type: ignore # noqa
 
-from .literal import READOUT_PLATFORMS, READOUT_TYPES
+from .vocabulary import READOUT_PLATFORMS, READOUT_TYPES
 
 
-def _todict(x) -> dict:
+def _todict(x: _LiteralGenericAlias) -> dict:
     return {
         i.translate({ord(c): "_" for c in "-. !@#$%^&*()[]{};:,/<>?|`~=+'\""}): i
         for i in get_args(x)
